<?php

namespace Drupal\Tests\codes_pool\Kernel\Entity;

use Drupal\codes_pool\Entity\CodeCollection;
use Drupal\codes_pool\Entity\CodeCollectionType;
use Drupal\KernelTests\KernelTestBase;

/**
 * Tests the code collection entity.
 *
 * @coversDefaultClass \Drupal\codes_pool\Entity\CodeCollection
 *
 * @group codes_pool
 */
class CodeCollectionTest extends KernelTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'codes_pool',
    'entity'
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->installEntitySchema('codes_pool_collection');
    $this->installConfig(['codes_pool']);
  }

  /**
   * @covers ::getName
   * @covers ::setName
   * @covers ::getDescription
   * @covers ::setDescription
   * @covers ::setSource
   * @covers ::getSourcePlugin
   * @covers ::getWeight
   * @covers ::setWeight
   * @covers ::getCodesCount
   * @covers ::getCountCodeAvailable
   * @covers ::hasCodeAvailable
   * @covers ::dispenseCode
   * @covers ::isEnabled
   * @covers ::setEnabled
   */
  public function testCodeCollection() {

    $code_collection_type = CodeCollectionType::create([
      'id' => 'test',
      'label' => 'Test label',
      'description' => 'Test description'
    ]);
    $code_collection_type->save();

    // @todo Actually set a bundle.
    $code_collection = CodeCollection::create([
      'status' => FALSE,
    ]);

    $code_collection->setName('March code collection');
    $this->assertEquals('March code collection', $code_collection->getName());

    $code_collection->setDescription('March 20% off code collection.');
    $this->assertEquals('March 20% off code collection.', $code_collection->getDescription());

    $code_collection->setEnabled(TRUE);
    $this->assertEquals(TRUE, $code_collection->isEnabled());
  }

}
